<a href="https://github.com/texnoforge/texnomagic/releases" alt="latest release"><img src="https://img.shields.io/github/v/release/texnoforge/texnomagic"/></a>
<a href="https://pypi.org/project/texnomagic/" alt="PyPI version"><img src="https://img.shields.io/pypi/v/texnomagic?color=blue"/></a>
<br>
<a href="https://github.com/texnoforge/texnomagic/actions/workflows/python-package.yml"><img alt="Python CI Status" src="https://github.com/texnoforge/texnomagic/actions/workflows/python-package.yml/badge.svg"></a>
<a href="https://github.com/texnoforge/texnomagic/actions/workflows/deploy-docs.yml"><img alt="Docs Status" src="https://github.com/texnoforge/texnomagic/actions/workflows/deploy-docs.yml/badge.svg"></a>
</p>


# [TexnoMagic docs online][docs]

## [TexnoMagic docs on GitLab](https://github.com/texnoforge/texnomagic/tree/master/docs)

## TexnoMagic docs offline

See docs/index.md and other files in docs/ directory.

You can also render docs into HTML using MkDocs:

    pip install mkdocs-material
    mkdocs build
    # see site/index.html

#### read the [docs] and have a nice magic ᕕ( ᐛ )ᕗ

[docs]: http://texnoforge.github.io/texnomagic
